@@ -8,7 +8,7 @@ use crate::common::*;
 impl Field {
     pub fn match_arm(&self) -> Ts2 {
         let Field {
-            const_ident,
+            const_ident_decode: const_ident,
             member,
             ty,
             ..
@@ -21,7 +21,7 @@ impl Field {
     pub fn const_def(&self, cty: &Ts2) -> Ts2 {
         let Field {
             clean_ty,
-            const_ident,
+            const_ident_decode: const_ident,
             cfg: FieldConfig { field_number, .. },
             ..
         } = self;
@@ -68,11 +68,7 @@ impl Field {
     }
 
     pub fn merge(&self) -> Ts2 {
-        let Field {
-            member,
-            ty,
-            ..
-        } = self;
+        let Field { member, ty, .. } = self;
 
         quote! {
             <#ty as ::otopr::__private::Decodable<'de>>::merge(&mut self.#member, other.#member);
@@ -126,7 +122,7 @@ pub(crate) fn derive_decodable_message(input: DeriveInput) -> syn::Result<Ts2> {
                 let tk = d.set_limit(len);
                 let message = <Self as ::otopr::__private::DecodableMessage<'de>>::decode(d);
                 d.reset_limit(tk);
-                Ok(message?)
+                message
             }
             fn merge(&mut self, other: Self) {
                 #(#merges)*
